__title__ = 'django-fobi'
__version__ = '0.3.1'
__build__ = 0x00000b
__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
__copyright__ = 'Copyright (c) 2014 Artur Barseghyan'
__license__ = 'GPL 2.0/LGPL 2.1'
